/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: French (http://www.transifex.com/tine20/tine20/language/fr/)\nLanguage: fr\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n > 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: "{0} {1} {2}"

, "Recurrances"
: "Récurrences"

, "No recurring rule defined"
: "Aucune récurrence de définie"

, "Details"
: "Détails"

, "None"
: "Aucun"

, "Daily"
: "Quotidien"

, "Weekly"
: "Hebdomadaire"

, "Monthly"
: "Mensuel"

, "Yearly"
: "Annuel"

, "Exceptions of reccuring events can't have recurrences themselves."
: "Les événement récurrents ne peuvent pas être modifiés"

, "at"
: "à"

, "never"
: "Jamais"

, "after {0} occurrences"
: "après {0} occurrences"

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "Fin"

, "Until has to be after event start"
: "La date de fin doit être postérieure à la date de début"

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: "Tous les {0} jours"

, "Every {0}. Week at"
: "Tous les {0} semaines le"

, "Every {0}. Month"
: "Tous les {0} mois"

, "at the"
: "le"

, "first"
: "premier"

, "second"
: "deuxième"

, "third"
: "troisième"

, "fourth"
: "quatrième"

, "last"
: "dernier"

, "Every {0}. Year"
: "Tous les {0}. Année"

, "of"
: "de"

, "Summary"
: "Résumé"

, "Organizer"
: "Organisateur"

, "Description"
: "Description"

, "Location"
: "Lieu"

, "Start Time"
: "Date de début"

, "End Time"
: "Date de fin"

, "Attendee"
: "Participant"

, "whole day"
: "Journée"

, "Week {0} :"
: "Semaine {0} :"

, "Poll, Polls"
: [
  ""
 ,""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "Nouvel événement"

, "Calendar, Calendars"
: [
  "Agenda"
 ,"Agendas"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: "Ajouter un participant"

, "Sort Attendee"
: "Classer les participants"

, "Check to filter for this attendee"
: "Filtrer pour ce participant"

, "Unavailable"
: ""

, "Loading events, please wait..."
: "Chargement, veuillez patienter..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "Imprimer la page"

, "Loose-Leaf"
: ""

, "Sheet"
: "Feuille"

, "Grid"
: "Grille"

, "Timeline"
: ""

, "Day"
: "Jour"

, "Week"
: "Semaine"

, "Month"
: "Mois"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: "Définir ma présence"

, "Copy {0}"
: "Copier {0}"

, "Set event status"
: ""

, "Updating event in the past"
: "Mettre à jour un événement passé"

, "Update this event"
: "Mettre à jour cet événement"

, "Do not update this event"
: "Ne pas mettre à jour cet événement"

, "Creating event in the past"
: "Créer un événement dans le passé"

, "Create this event"
: "Créer cet événement"

, "Do not create this event"
: "Ne pas créer cet événement"

, "Update this event only"
: "Mettre à jour ce seul événement"

, "Update this and all future events"
: "Mettre à jour cet événement et tous les prochains"

, "Update whole series"
: "Mettre à jour toute la série"

, "Update nothing"
: "Ne rien mettre à jour"

, "Update Event"
: "Mettre à jour l'événement"

, "Please Change Selection"
: "Veuillez Changer la sélection"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: "La sélection contient des événements récurrents. Les événements récurrents doivent être supprimés séparément !"

, "Delete Event"
: "Supprimer"

, "Delete this event only"
: "Supprimer cet événement seulement"

, "Delete this and all future events"
: "Supprimer cet événement et tous les suivants"

, "Delete whole series"
: "Supprimer toute la série"

, "Delete nothing"
: "Ne rien supprimer"

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  "Êtes-vous sûr de vouloir supprimer l'événement sélectionné?"
 ,"Êtes-vous sûr de vouloir supprimer les {0} événements sélectionnés?"

]
, "Could not Print"
: "L'impression a échoué"

, "Sorry, your current view does not support printing."
: "Cette vue ne peut pas être imprimée"

, "Scheduling Conflict"
: "Conflit de planification"

, "The following attendee are busy at the requested time:"
: "Le participant suivant est déjà occupé à l'heure demandée :"

, "Ignore Conflict"
: "Ignorer le conflit"

, "Edit Event"
: "Modifier l'événement"

, "Cancel this action"
: "Annuler"

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "Gérer les ressources"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "Sélectionner un participant"

, "Attachments"
: ""

, "Private"
: "Privé"

, "Tags"
: "Tags"

, "Blocking"
: "Bloquant"

, "Tentative"
: "Tentative"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: "Classer en privé"

, "recurring event"
: "événement récurrent"

, "recurring event exception"
: "Erreur dans la récurrence de l'événement"

, "has alarm"
: "rappel activé"

, "has attachments"
: "a une pièce jointe"

, "is part of an open poll"
: ""

, "Mini Calendar"
: "Mini-calendrier"

, "WK"
: "WK"

, "{0} more..."
: "{0} de plus..."

, "Resource Grant, Resource Grants"
: [
  ""
 ,""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: "Veuillez sélectionner l'événement auquel les contacts seront ajoutés"

, "Role"
: "Rôle"

, "Select Role"
: "Sélectionner un role"

, "Status"
: "Statut"

, "Select Status"
: "Sélectionner un statut"

, "Adding {0} Attendee to event"
: "Ajout de {0} participants à l'événement"

, "no events found"
: "Aucun événement trouvé"

, "Searching..."
: "Recherche ..."

, "Search Event"
: "Recherche d'événement"

, "Event, Events"
: [
  "Événement"
 ,"Événements"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: "Non bloquant"

, "Displayed in"
: "Marqué dans"

, "No Information"
: "Pas d'information"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "Événements"

, "Calendars"
: "Agendas"

, "Quick Search"
: "Recherche rapide"

, "GENDER_Calendar"
: ""

, "Attendee Status"
: "Présence du participant"

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: "Role du participant"

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: "Catégorie"

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: "{0} {1} heure"

, "Event (as attendee)"
: "Evènement (participant)"

, "Event (as organizer)"
: "Evènement (Organisateur)"

, "Event attendee"
: "Participant"

, "Attender, Attendee"
: [
  "Participant"
 ,"Participants"

]
, "Resource, Resources"
: [
  "Ressource"
 ,"Ressources"

]
, "Resources"
: "Ressources"

, "Anyone"
: ""

, "Name"
: "Nom"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "Email"

, "Maximum number of attendee"
: ""

, "Type"
: "Type"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: "Cliquez ici pour ajouter un participant..."

, "User"
: "Utilisateur"

, "Group"
: "Groupe"

, "Member of group"
: "Membre du groupe"

, "This is the calendar where the attender has saved this event in"
: "Agenda où le participant a enregistré cet événement"

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "Supprimer le participant"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: "(comme membre du groupe)"

, "External Attendee"
: "Participant externe"

, "Originally"
: "À l'origine"

, "Checking Calendar Data..."
: "Vérification des agendas"

, "Reply to Recurring Event"
: "Répondre à l'événement récurrent"

, "You are responding to an recurring event. What would you like to do?"
: "Vous êtes en train de répondre à un événement récurrent. Que vous voulez faire ?"

, "Respond to whole series"
: "Répondre à toute la série"

, "Do not respond"
: "Ne pas répondre"

, "The event of this message does not exist"
: "L'événement de ce message n'existe pas"

, "The sender is not authorised to update the event"
: "Vous ne pouvez pas modifier l'événement"

, "This message is already processed"
: "Ce message a déjà été traité"

, "You are not an attendee of this event"
: "Vous ne participez pas à cet événement"

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: "Message non supporté"

, "This is an event invitation for someone else."
: "Cette invitation ne concerne pas ce compte."

, "You have already replied to this event invitation."
: "Vous avez déjà répondu à cette invitation"

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: "Vous avez reçu une invitation. Quelle est votre réponse ?"

, "An invited attendee responded to the invitation."
: "Un participant a répondu à l'invitation"

, "Unsupported method"
: "Méthode non supportée"

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "Saisissez une description..."

, "Grants"
: "Droits"

, "This event is originally stored in a calendar you don't have access to."
: "Cet événement est marqué dans un agenda auquel vous n'avez pas accès."

, "This event is originally stored in {0}"
: "Cet événement est marqué dans {0}"

, "This event is additionally displayed in your personal calendar {0}"
: "Cet événement est également affiché dans votre agenda personnel {0}"

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: "Voir en tant que"

, "Saved in"
: "Sauvegardé"

, "Enter description"
: "Saisir une description"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "Date de fin invalide"

, "End date must be after start date"
: "La date de fin doit être postérieure à la date de début"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "Date de début non valide"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: "Le résumé ne doit pas dépasser 255 caractères"

, "The summary must have at least 1 character."
: "Le résumé est obligatoire"

, "Summary too Long"
: "Résumé trop long"

, "Summary too Short"
: "Résumé obligatoire"

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: "Tous mes événements"

, "Position on the left time axis, day and week view should start with"
: "Début des vues \"Jour\" et \"Semaine\" sur l'axe du temps"

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "Agenda par défaut"

, "The default calendar for invitations and new events"
: "Agenda par défaut pour les invitations et les nouveau événements"

, "Default Favorite"
: "Favoris par défaut"

, "The default favorite which is loaded on calendar startup"
: "Les favoris chargés par défaut au démarrage du gestionnaire d'agenda"

, "Get Notification Emails"
: "Recevoir les courriels de notification"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "Niveau des actions dont vous voulez être notifié. Les organisateurs seront notifiés de toutes les mises à jour, incluant les réponses des participants, à moins que cette préférence soit définie à \"Jamais\""

, "Send Notifications Emails of own Actions"
: "Envoyer une notification de ses propres actions"

, "Get notifications emails for actions you did yourself"
: "Recevoir des notification par courriels de vos propres actions"

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: "Activer l'alarme"

, "New events get a standard alarm as defined below"
: "Les nouveaux événements auront un rappel comme indiqué"

, "Standard Alarm Time"
: "Alarme"

, "Minutes before the event starts"
: "Minutes avant le début de l'événement"

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "Agendas fixes"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: "Jamais"

, "On invitation and cancellation only"
: "Sur invitation et annulation uniquement"

, "On time changes"
: "Sur modification de la date / heure"

, "On all updates but attendee responses"
: "Sur toutes les mises à jour sauf réponse d'un participant"

, "On attendee responses too"
: "Sur toutes les mises à jour y compris réponse d'un participant"

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "Agendas qui sont toujours sélectionnés quelque soit le filtre. Par exemple, vous pouvez forcer le calendrier des jours fériés."

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "Statuts disponibles pour un participant"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "Pas de réponse"

, "Accepted"
: "Accepté"

, "Declined"
: "Refusé"

, "Attendee Roles Available"
: "Roles disponibles pour un participant"

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "Requis"

, "Optional"
: "Facultatif"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "Agenda personnel de %s"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "inconnu"

, "This contact has been automatically added by the system as an event attender"
: "Ce contact a été ajouté automatiquement comme participant"

, "The email address has been shortened:"
: ""

, "Every %s day"
: "Tous les %s jours"

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: "Tous les %1$s mois le %2$s %3$s"

, "Monthly every %1$s %2$s"
: "Chaque mois le %1$s %2$s"

, "Every %1$s month on the %2$s"
: "Tous les %1$s mois le %2$s"

, "Monthly on the %1$s"
: "Tous les %1$s du mois"

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: "Chaque année, tous les %1$s du mois de %2$s"

, "second to last"
: "Avant-dernier"

, "fifth"
: "cinquième"

, "st"
: "er"

, "nd"
: "ème"

, "rd"
: "ème"

, "th"
: "ème"

, "Start"
: "Début"

, "Priority"
: "Priorité"

, "Url"
: "Site Internet"

, "Recurrance rule"
: "Récurrences"

, "Is all day event"
: "Toute la journée"

, "Organizer timezone"
: "Fuseau horaire de l'organisateur"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: "Rappel pour l'événement \"%1$s\" à %2$s"

, "Event invitation \"%1$s\" at %2$s"
: "Invitation pour \"%1$s\" à %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "L'événement \"%1$s\" à %2$s a été annulé"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: "Evènenement\"%1$s\" a été replanifié de %2$s à %3$s"

, "Event \"%1$s\" at %2$s has been updated"
: "L'événement \"%1$s\" à %2$s a été mis à jour"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s a accepté \"%2$s\" à %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s a refusé \"%2$s\" à %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: "%1$s tentera de participer à l'événement \"%2$s\" à %3$s"

, "No response from %1$s for event \"%2$s\" at %3$s"
: "Pas de réponse de %1$s pour l'événement \"%2$s\" à %3$s"

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: "Changement de participants pour l'événement \"%1$s\" à %2$s"

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "Mises à jour"

, "This is an event series exception."
: "C'est une exception à la série d'événements"

, "%1$s changed from \"%2$s\" to \"%3$s\""
: "%1$s déplacé de \"%2$s\" à \"%3$s\""

, "%1$s has been invited"
: "%1$s a été invité"

, "%1$s has been removed"
: "%1$s a été retiré"

, "%1$s accepted invitation"
: "%1$s a accepté l'invitation"

, "%1$s declined invitation"
: "%1$s a décliné l'invitation"

, "Tentative response from %1$s"
: "Participation incertaine de %1$s"

, "No response from %1$s"
: "Pas de réponse de %1$s"

, "\"%2$s\" response from %1$s"
: "\"%2$s\" réponse de %1$s"

, "Link"
: ""

, "Event details"
: "Détails de l'événement"

, "All events I attend"
: "Tous les événements auxquels j'assiste"

, "Awaiting response"
: "En attente de la réponse"

, "Events I have not yet responded to"
: "Evènements auxquels je n'ai pas encore répondu"

, "Declined events"
: "Evènements refusés"

, "Events I have declined"
: "Evènements que j'ai refusé"

, "I'm organizer"
: "Je suis organisateur"

, "Events I'm the organizer of"
: "Evènements dont je suis l'oganisateur"

, "manage shared calendars"
: "gérer les agendas partagés"

, "Create new shared calendars"
: "Créer de nouveaux agendas partagés"

, "manage shared calendars favorites"
: "gérer les favoris des agendas partagés"

, "Create or update shared calendars favorites"
: "Créer ou mettre à jour les favoris des agendas partagés"

, "manage resources"
: "gérer les ressources"

, "All Rights to administrate resources"
: "Tous les droits d'administration des ressources"

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""
 ,""

]
, "Poll"
: ""

, "Calendar"
: "Agenda"

, "Do you really want to delete this event?"
: "Êtes-vous sûr de vouloir supprimer l'événement sélectionné?"

, "Resource Grant"
: ""

, "Event"
: "Événement"

, "Attender"
: "Participant"

, "Resource"
: "Ressource"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
